@@ -30,6 +30,9 @@ impl<T> DigraphNodeRef<T> {
             rc
         }
     }
+    pub fn is_none(&self) -> bool {
+        self.rc.is_none()
+    }
     pub fn remove(&mut self) -> bool {
         if let Some(rc) = self.rc.clone() {
             self.rc = rc.next.rc.clone();
@@ -60,6 +63,9 @@ impl<T> DigraphNodeRef<T> {
             underlying: self.clone()
         }
     }
+    pub fn is_empty(&self) -> bool {
+        self.rc.is_none()
+    }
 }
 
 impl<T> Clone for DigraphNodeRef<T> {
@@ -106,6 +112,18 @@ mod tests {
         assert_eq!(list.values().collect::<Vec<i32>>(), (0..10).rev().collect::<Vec<i32>>());
     }
 
+    #[test]
+    fn pass_two_times() {
+        let mut list = DigraphNodeRef::new();
+        for i in 0..10 {
+            list.prepend(i);
+        }
+        let iter = list.clone();
+        assert_eq!(iter.values().collect::<Vec<i32>>(), (0..10).rev().collect::<Vec<i32>>());
+        let iter = list.clone();
+        assert_eq!(iter.values().collect::<Vec<i32>>(), (0..10).rev().collect::<Vec<i32>>());
+    }
+
     #[test]
     fn remove() {
         let mut list = DigraphNodeRef::new();
